export class FrequencyCounter {
    private wordFrequency: Map<string, number>;
    private maxFrequency: number;
    private weightedWords: Map<string, number>;

    constructor(weightedWords: Map<string, number> = new Map()) {
        this.wordFrequency = new Map();
        this.maxFrequency = 0;
        this.weightedWords = weightedWords;
    }

    public registerWord(word: string): void {
        const currentFrequency = this.wordFrequency.get(word) || 0;
        const newFrequency = currentFrequency + 1;
        this.wordFrequency.set(word, newFrequency);

        if (newFrequency > this.maxFrequency) {
            this.maxFrequency = newFrequency;
        }
    }

    public getWeight(word: string): number {
        let weight = 0;

        if (this.maxFrequency > 0) {
            const frequency = this.wordFrequency.get(word) || 0;
            weight += (frequency / this.maxFrequency) * 2; // You can adjust the multiplier as needed
        }

        if (this.weightedWords.has(word)) {
            weight += this.weightedWords.get(word)!;
        }

        return weight;
    }
}