import { levenshtein } from './levenshtein';
import { FrequencyCounter } from './frequencycounter';

export class AutoCorrect {
  private dictionary: string[];
  private frequencyCounter: FrequencyCounter;

  constructor(dictionary: string[]) {
    this.dictionary = dictionary;
    this.frequencyCounter = new FrequencyCounter();
  }

  public registerTypedWord(word: string): void {
    this.frequencyCounter.registerWord(word);
  }

  public correct(word: string, tolerance: number = 2): string | null {
    let minDistance = Infinity;
    let bestMatch: string | null = null;

    for (const entry of this.dictionary) {
      let distance = levenshtein(word, entry);

      // Apply weight based on word frequency
      const weight = this.frequencyCounter.getWeight(entry);
      distance -= weight;
      distance = Math.max(distance, 0); // Ensure distance doesn't become negative

      if (distance < minDistance) {
        minDistance = distance;
        bestMatch = entry;
      }
    }

    return minDistance <= tolerance ? bestMatch : null;
  }
}