import { Container } from "./container";
import { UINode } from "./node";
import { UIWindow } from "./window";
import { Button } from "./button";

export class Dialog<T> extends UIWindow {
    private resolvePromise: (value: T | PromiseLike<T>) => void;
    private rejectPromise: (reason?: any) => void;
    private promise: Promise<T>;
    private okButton: Button;
    private cancelButton: Button;

    private previouslyFocusedElement: HTMLElement;

    public constructor(title: string) {
        super(title, "dialog", false);
        this.promise = new Promise<T>((resolve, reject) => {
            this.resolvePromise = resolve;
            this.rejectPromise = reject;
        });

        // Automatically add OK and Cancel buttons
        this.okButton = new Button("OK");
        this.okButton.setPosition(70, 90, 10, 5);
        this.okButton.onClick(() => this.choose(undefined)); // Default OK action

        this.cancelButton = new Button("Cancel");
        this.cancelButton.setPosition(20, 90, 10, 5);
        this.cancelButton.onClick(() => this.cancel()); // Default Cancel action
    }

    public setOkAction(action: () => T): void {
        this.okButton.onClick(() => {
            const result = action();
            this.choose(result);
        });
    }

    public setCancelAction(action: () => void): void {
        this.cancelButton.onClick(() => {
            action();
            this.cancel();
        });
    }

    public choose(item: T) {
        this.resolvePromise(item);
        document.body.removeChild(this.getElement());
        this.hide();
        this.previouslyFocusedElement.focus();
    }

    public cancel(reason?: any) {
        this.rejectPromise(reason);
        document.body.removeChild(this.getElement());
        this.hide();
        this.previouslyFocusedElement.focus();
    }

    public open(): Promise<T> {
        this.previouslyFocusedElement = document.activeElement as HTMLElement;
        document.body.appendChild(        this.show());
        this.add(this.okButton);
        this.add(this.cancelButton);
        this.container.focus();

        return this.promise;
    }
}
