import { UINode } from "./node";

export class Dropdown extends UINode {
    private id: string;
    private titleElement: HTMLLabelElement;
    private selectElement: HTMLSelectElement;
    public constructor(title: string, options: { key: string; value: string }[]) {
        super(title);
        this.id = Math.random().toString();
        this.titleElement = document.createElement("label");
        this.titleElement.innerText = title;
        this.titleElement.id = `dd_title_${this.id}`;
        this.selectElement = document.createElement("select");
        this.selectElement.id = `dd_${this.id}`;
        this.titleElement.appendChild(this.selectElement);
        this.element.appendChild(this.titleElement);

        options.forEach((option) => {
            const optionElement = document.createElement("option");
            optionElement.value = option.key;
            optionElement.innerText = option.value;
            this.selectElement.appendChild(optionElement);
        });
    }

    public focus() {
        this.selectElement.focus();
    }

    public getElement(): HTMLElement {
        return this.selectElement;
    }

    public setText(text: string) {
        this.title = text;
        this.titleElement.innerText = text;
    }

    public getSelectedValue(): string {
        return this.selectElement.value;
    }

    public setSelectedValue(value: string) {
        this.selectElement.value = value;
    }
}